test_dir =	'tests'		# Location of testsuite file (relative to current directory)

database = 	'sample'	# Database to connect to
user     =	'db2inst1'	# User ID to connect with
password = 	'password'	# Password for given User ID
hostname = 	'localhost'	# Hostname
port     =	60000		# Port Number
